@@ -324,7 +324,10 @@ REPORT_TYPE_METRIC_MAPPING = {
                                       'viewAttributedSalesNewToBrand14d',
                                       'viewAttributedUnitsOrderedNewToBrand14d',
                                       'attributedBrandedSearches14d',
-                                      'viewAttributedBrandedSearches14d'],
+                                      'viewAttributedBrandedSearches14d',
+                                      'attributedSales7d',  # 2022-10-11发现接口实际支持而文档缺没有描述
+                                      'attributedSalesNewToBrand14d',  # 2022-10-11发现接口实际支持而文档缺没有描述
+                                      ],
                  },
     'productAds': {'T00020': ['campaignName',
                               'campaignId',
@@ -571,7 +574,9 @@ REPORT_TYPE_METRIC_MAPPING = {
                                      'viewAttributedSalesNewToBrand14d',
                                      'viewAttributedUnitsOrderedNewToBrand14d',
                                      'attributedBrandedSearches14d',
-                                     'viewAttributedBrandedSearches14d'],
+                                     'viewAttributedBrandedSearches14d',
+                                     'viewImpressions',  # 2022-10-11发现接口实际支持而文档缺没有描述
+                                     ],
                 },
 
     # Unsupported fields for asin report: attributedDetailPageView14d,viewAttributedDetailPageView14d,costType.
